@@ -32,7 +32,7 @@ public class AppBar extends HBox {
 	 * Creates new instance of AppBar.
 	 */
 	public AppBar(boolean hasProgress, boolean hasStatus, PreferencesType type) {
-		setHandle(gnome_appbar_new(hasProgress, hasStatus, type.getValue()));
+		super(gnome_appbar_new(hasProgress, hasStatus, type.getValue()));
 		initializeEventHandlers();
 	}
 
@@ -40,10 +40,7 @@ public class AppBar extends HBox {
 	 * Construct an AppBar using a handle to a native resource.
 	 */
 	public AppBar(int handle) {
-		setHandle(handle);
-	}
-
-	protected void noopInit() {
+		super(handle);
 	}
 
 	/**
@@ -202,16 +199,23 @@ public class AppBar extends HBox {
 	}
 
 	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			super.initializeEventHandlers();
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
-		return evtMap.getListenerClass(signal);
+		Class cls = evtMap.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
+		return cls;
 	}
 
 	public GtkEventType getEventType(String signal) {
-		return evtMap.getEventType(signal);
+		GtkEventType et = evtMap.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
+		return et;
 	}
 
 	private static EventMap evtMap = new EventMap();
