@@ -23,13 +23,7 @@ public class Canvas extends Layout {
 	 * Constructs a new Canvas.
 	 */
 	public Canvas() {
-		noopInit();
-	}
-
-	protected void noopInit() {
-		if (-1 == getHandle()) {
-			setHandle(gnome_canvas_new());
-		}
+		super(gnome_canvas_new());
 	}
 
 	/**
@@ -37,7 +31,7 @@ public class Canvas extends Layout {
 	 * @param handle The handle to the native resource.
 	 */
 	public Canvas(int handle) {
-	    setHandle(handle);
+	    super(handle);
 	}
 	
 	/**
